==> mutual_credit-5.0.12.tar.gz: mutual_credit/src/Entity/Query/TransactionQuery.php <==
<?php

namespace Drupal\mcapi\Entity\Query;

use Drupal\Core\Entity\Query\Sql\Query as BaseQuery;
use Drupal\Core\Entity\ContentEntityInterface;

/**
 * The SQL storage entity query class.
 *
 * Extended to handle new methods to filter by wallets and wallet holders
 */
class TransactionQuery extends BaseQuery {

  /**
   * Filter the entityQuery to include only transactions in which the given
   * entity is payer or payee
   *
   * @param ContentEntityInterface $entity
   * @return \Drupal\mcapi\Entity\TransactionQuery
   */
  public function involving(ContentEntityInterface $entity) {
    $group = $this->orConditionGroup()
      ->condition('payer', (array) $entity->id(), 'IN')
      ->condition('payee', (array) $entity->id(), 'IN');
    $this->condition($group);
    return $this;
  }

  public function noChildren() {
    $this->condition('type', 'inherit', '<>');
    return $this;
  }

  /**
   * Prepares the basic query with proper metadata/tags and base fields.
   *
   * @return \Drupal\Core\Entity\Query\Sql\Query
   *   Returns the called object.
   *
   * @throws \Drupal\Core\Entity\Query\QueryException
   *   Thrown if the base table does not exist.
   */
  protected function prepare() {
    $this->sqlQuery = $this->connection->select(
      'mcapi_transaction',
      'base_table',
      ['conjunction' => $this->conjunction]
    );
    $this->sqlQuery->addMetaData('entity_type', 'mcapi_transaction');
    // Add the key field for fetchAllKeyed().
    $this->sqlFields["base_table.xid"] = ['base_table', 'xid'];

    // Now add the value column for fetchAllKeyed(), the serial number
    $this->sqlFields["base_table.serial"] = ['base_table', 'serial'];

    if ($this->accessCheck) {
      $this->sqlQuery->addTag('mcapi_transaction_access');
    }

    $this->sqlQuery->addTag('entity_query');
    $this->sqlQuery->addTag('entity_query_mcapi_transaction');

    return $this;
  }

}

==> mutual_credit-5.1.0.tar.gz: mutual_credit/src/Entity/Query/TransactionQuery.php <==
<?php

namespace Drupal\mcapi\Entity\Query;

use Drupal\Core\Entity\Query\Sql\Query as BaseQuery;
use Drupal\Core\Entity\ContentEntityInterface;

/**
 * The SQL storage entity query class.
 *
 * Extended to handle new methods to filter by wallets and wallet holders
 */
class TransactionQuery extends BaseQuery {

  /**
   * Filter the entityQuery to include only transactions in which the given
   * entity is payer or payee
   *
   * @param ContentEntityInterface $entity
   * @return \Drupal\mcapi\Entity\TransactionQuery
   */
  public function involving(ContentEntityInterface $entity) {
    $group = $this->orConditionGroup()
      ->condition('payer', (array) $entity->id(), 'IN')
      ->condition('payee', (array) $entity->id(), 'IN');
    return $this->condition($group);
  }

  public function noChildren() {
    return $this->condition('type', 'inherit', '<>');
  }

  /**
   * Prepares the basic query with proper metadata/tags and base fields.
   *
   * @return \Drupal\Core\Entity\Query\Sql\Query
   *   Returns the called object.
   *
   * @throws \Drupal\Core\Entity\Query\QueryException
   *   Thrown if the base table does not exist.
   */
  protected function prepare() {
    $this->sqlQuery = $this->connection->select(
      'mcapi_transaction',
      'base_table',
      ['conjunction' => $this->conjunction]
    );
    $this->sqlQuery->addMetaData('entity_type', 'mcapi_transaction');
    // Add the key field for fetchAllKeyed().
    $this->sqlFields["base_table.xid"] = ['base_table', 'xid'];

    // Now add the value column for fetchAllKeyed(), the serial number
    $this->sqlFields["base_table.serial"] = ['base_table', 'serial'];

    if ($this->accessCheck) {
      $this->sqlQuery->addTag('mcapi_transaction_access');
    }

    $this->sqlQuery->addTag('entity_query');
    $this->sqlQuery->addTag('entity_query_mcapi_transaction');
    return $this;
  }

}
